import { useState } from "react";
import { Menu, X, ChevronDown } from "lucide-react";
import { Link, useLocation } from "wouter";
import logoPath from "@assets/RGLogo.webp";

const navigationItems = [
  { name: "Home", href: "/" },
  { name: "Buy", href: "/buy" },
  { name: "Sales", href: "/sales" },
  { name: "Landlords", href: "/landlords" },
  { 
    name: "Tenants", 
    href: "/rent",
    dropdown: [
      { name: "Tenant Registration Form", href: "/tenant-registration" },
      { name: "Tenant Application Form", href: "/apply" },
      { name: "Maintenance Request", href: "/maintenance" }
    ]
  },
  { name: "Mortgages", href: "/mortgages" },
  { name: "About Us", href: "/about" },
  { name: "Contact", href: "/contact" },
  { name: "Blog", href: "/blog" },
];

export default function Navigation() {
  const [isOpen, setIsOpen] = useState(false);
  const [dropdownOpen, setDropdownOpen] = useState<string | null>(null);
  const [location] = useLocation();

  return (
    <nav className="shadow-sm border-b border-gray-700 sticky top-0 z-50" style={{ backgroundColor: '#2A2733' }}>
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="flex justify-between items-center h-16 md:justify-start">
          {/* Mobile and Tablet menu button - Left side */}
          <div className="md:hidden">
            <button
              onClick={() => setIsOpen(!isOpen)}
              className="text-white hover:text-red-400 p-2 transition-colors duration-200"
            >
              {isOpen ? <X className="h-6 w-6" /> : <Menu className="h-6 w-6" />}
            </button>
          </div>

          {/* Logo - Centered on mobile, left on desktop */}
          <div className="flex-shrink-0 flex items-center absolute left-1/2 transform -translate-x-1/2 md:relative md:left-auto md:transform-none">
            <Link href="/" className="flex items-center">
              <img src={logoPath} alt="RG Property" className="h-10 w-auto" />
            </Link>
          </div>
          
          {/* Desktop Navigation */}
          <div className="hidden md:flex md:items-center md:flex-1">
            <div className="ml-4 lg:ml-10 flex items-baseline space-x-2 lg:space-x-6 xl:space-x-8">
              {navigationItems.map((item) => (
                <div key={item.name} className="relative">
                  {item.dropdown ? (
                    <div 
                      className="relative"
                      onMouseEnter={() => setDropdownOpen(item.name)}
                      onMouseLeave={() => setDropdownOpen(null)}
                    >
                      <Link
                        href={item.href}
                        className={`px-1 lg:px-3 py-2 rounded-md text-xs lg:text-sm font-medium transition-colors duration-200 flex items-center ${
                          location === item.href || item.dropdown?.some(sub => sub.href === location)
                            ? "text-red-500 font-semibold"
                            : "text-white hover:text-red-400"
                        }`}
                      >
                        {item.name}
                        <ChevronDown className="ml-1 h-3 w-3 lg:h-4 lg:w-4" />
                      </Link>
                      {dropdownOpen === item.name && (
                        <div className="absolute top-full left-0 w-48 bg-white rounded-md shadow-lg z-50">
                          <div className="py-1">
                            {item.dropdown.map((subItem) => (
                              <Link
                                key={subItem.name}
                                href={subItem.href}
                                className="block px-4 py-2 text-sm text-gray-700 hover:bg-gray-100 hover:text-gray-900"
                              >
                                {subItem.name}
                              </Link>
                            ))}
                          </div>
                        </div>
                      )}
                    </div>
                  ) : (
                    <Link
                      href={item.href}
                      className={`px-1 lg:px-3 py-2 rounded-md text-xs lg:text-sm font-medium transition-colors duration-200 ${
                        location === item.href
                          ? "text-red-500 font-semibold"
                          : "text-white hover:text-red-400"
                      }`}
                    >
                      {item.name}
                    </Link>
                  )}
                </div>
              ))}
            </div>
            
            {/* Call Us Now Button - Desktop */}
            <div className="ml-auto">
              <a 
                href="tel:01174625777"
                className="bg-red-600 hover:bg-red-700 text-white font-semibold px-4 py-2 rounded-lg transition-colors duration-200"
              >
                Call Us Now
              </a>
            </div>
          </div>

          {/* Call Us Now Button - Mobile */}
          <div className="md:hidden">
            <a 
              href="tel:01174625777"
              className="bg-red-600 hover:bg-red-700 text-white font-semibold px-3 py-2 rounded-lg text-sm transition-colors duration-200"
            >
              Call Us Now
            </a>
          </div>
        </div>
      </div>

      {/* Mobile Navigation Menu */}
      {isOpen && (
        <div className="md:hidden border-t border-gray-700" style={{ backgroundColor: '#2A2733' }}>
          <div className="px-2 pt-2 pb-3 space-y-1">
            {navigationItems.map((item) => (
              <div key={item.name}>
                {item.dropdown ? (
                  <div>
                    <div className="flex items-center">
                      <Link
                        href={item.href}
                        className={`flex-1 px-3 py-2 rounded-md text-base font-medium transition-colors duration-200 ${
                          location === item.href || item.dropdown?.some(sub => sub.href === location)
                            ? "text-red-500 font-semibold"
                            : "text-white hover:text-red-400"
                        }`}
                        onClick={() => setIsOpen(false)}
                      >
                        {item.name}
                      </Link>
                      <button
                        className="px-2 py-2 text-white hover:text-red-400"
                        onClick={() => setDropdownOpen(dropdownOpen === item.name ? null : item.name)}
                      >
                        <ChevronDown className="h-4 w-4" />
                      </button>
                    </div>
                    {dropdownOpen === item.name && (
                      <div className="ml-4 mt-1 space-y-1">
                        {item.dropdown.map((subItem) => (
                          <Link
                            key={subItem.name}
                            href={subItem.href}
                            className="block px-3 py-2 rounded-md text-sm text-gray-300 hover:text-red-400"
                            onClick={() => setIsOpen(false)}
                          >
                            {subItem.name}
                          </Link>
                        ))}
                      </div>
                    )}
                  </div>
                ) : (
                  <Link
                    href={item.href}
                    className={`block px-3 py-2 rounded-md text-base font-medium transition-colors duration-200 ${
                      location === item.href
                        ? "text-red-500 font-semibold"
                        : "text-white hover:text-red-400"
                    }`}
                    onClick={() => setIsOpen(false)}
                  >
                    {item.name}
                  </Link>
                )}
              </div>
            ))}
          </div>
        </div>
      )}
    </nav>
  );
}